@@ -10,7 +10,7 @@ import sklearn.metrics as mt
 
 
 # Class to hold and train many models (CB, XGB and LGB) on the same dataset
-class GBMFitter():
+class GBMFitter:
     def __init__(self, cb_data=[], xgb_data=[], lgb_data=[], cv_strategy=None, cv_groups=None, use_rounders=False, metrics=['rmse']):
         """Generates models in a CV manner for all 3 libraries algorithms
 
